@@ -27,8 +27,8 @@
  * \brief 赤黒木
  * \author KATO Noriaki <katono@users.sourceforge.jp>
  * \date 2006-10-29
- * $URL: http://svn.sourceforge.jp/svnroot/cstl/tags/rel-0.4.0/cstl/rbtree.h $
- * $Id: rbtree.h 181 2007-12-11 00:48:23Z katono $
+ * $URL: http://svn.sourceforge.jp/svnroot/cstl/tags/rel-0.5.0/cstl/rbtree.h $
+ * $Id: rbtree.h 215 2008-06-10 04:32:18Z katono $
  *
  * このファイルを直接インクルードしないこと
  */
@@ -95,7 +95,7 @@ static void Name##RBTreeNode_set_left(Name##RBTreeNode *self, Name##RBTreeNode *
 static void Name##RBTreeNode_set_right(Name##RBTreeNode *self, Name##RBTreeNode *t);\
 static Name##RBTreeNode *Name##RBTree_get_root(Name##RBTree *self);\
 static void Name##RBTree_set_root(Name##RBTree *self, Name##RBTreeNode *t);\
-static Name##RBTreeNode *Name##RBTreeNode_find(Name##RBTree *self, Name##RBTreeNode *t, KeyType key);\
+static Name##RBTreeNode *Name##RBTreeNode_find(Name##RBTreeNode *t, KeyType key);\
 static Name##RBTreeNode *Name##RBTreeNode_replace_subtree(Name##RBTreeNode *self, Name##RBTreeNode *t);\
 static void Name##RBTreeNode_swap_parent_child(Name##RBTreeNode *p, Name##RBTreeNode *c);\
 static void Name##RBTreeNode_swap(Name##RBTreeNode *s, Name##RBTreeNode *t);\
@@ -196,7 +196,7 @@ static int Name##RBTree_empty(Name##RBTree *self)\
 	return CSTL_RBTREE_NODE_IS_NIL(Name##RBTree_get_root(self), Name##RBTree);\
 }\
 \
-static Name##RBTreeNode *Name##RBTreeNode_find(Name##RBTree *self, Name##RBTreeNode *t, KeyType key)\
+static Name##RBTreeNode *Name##RBTreeNode_find(Name##RBTreeNode *t, KeyType key)\
 {\
 	register int cmp;\
 	while (!CSTL_RBTREE_NODE_IS_NIL(t, Name##RBTree)) {\
@@ -216,7 +216,7 @@ static Name##RBTreeIterator Name##RBTree_find(Name##RBTree *self, KeyType key)\
 {\
 	Name##RBTreeNode *t;\
 	assert(CSTL_RBTREE_NODE_IS_HEAD(self) && "RBTree_find");\
-	t = Name##RBTreeNode_find(self, Name##RBTree_get_root(self), key);\
+	t = Name##RBTreeNode_find(Name##RBTree_get_root(self), key);\
 	return CSTL_RBTREE_NODE_IS_NIL(t, Name##RBTree) ? Name##RBTree_end(self) : t;\
 }\
 \
@@ -778,7 +778,7 @@ Name *Name##_new(void)\
 \
 void Name##_delete(Name *self)\
 {\
-	assert(self && "RBTree_delete");\
+	if (!self) return;\
 	assert(self->magic == self && "RBTree_delete");\
 	Name##RBTree_delete(self->tree);\
 	CSTL_RBTREE_MAGIC(self->magic = 0);\
